(*$U-*)

(*$I Bench.inc *)                  (* Graphik Treiber entfaellt bei IBM *)


Var
  i        : Integer;
  ta,te,td : Real;
  td_MTX   : Array (.1..7.) of Real;
  Mittel   : Array (.1..3.) of Real;
  Takt     : Real;

Const
  bw80 : Integer = 2;
  td_XT4   : Array (.1..7.) of Real = (64.2,6.6,1.2,39.1,56.3,10.0,50.0);
  td_MTX4  : Array (.1..7.) of Real = (17.0,3.0,7.0,56.0,98.0,08.0,20.0);

(* TIME - Funktion fuer MTX 512 mit RAM 4.2 *)
(* ---------------------------------------- *)
Function Time : Real;

Var
  h,min,sec : Byte;

Begin
  Write (#27,'[U');
  sec := Mem (.$4B.);
  min := Mem (.$4C.);
  h   := Mem (.$4D.);
  Time := h*3600+min*60+sec;
End;

{
(* TIME - Funktion fuer IBM *)
(* ------------------------ *)

Function Time : Real;
Type
  ParRec = Record
             ax,bx,cx,dx,bp,si,di,ds,es,flags : Integer;
           End;

Var
  DosPar : ParRec;

Begin
  With DosPar Do Begin
    ax := $2C00;
    intr ($21,DosPar);
    Time := hi(cx)*3600+lo(cx)*60+hi(dx)+lo(dx)/100;
  End;
End;
}

Procedure Intmath;

Var
  i,j,x,y : Integer;

Begin
  ta := Time;
  x:=0;
  y:=3;
  WriteLn ('Start Int');
{
  For j:=1 to 10 Do
}
  For i:=1 to 10000 Do x:=x+(y*y-y) Div y;
  te:=Time;
  td:=te-ta;
  WriteLn ('Ende von Int ',x);
  WriteLn ('Zeit : ',Round(td));
End;

Procedure Realmath;

Var
  i: Integer;
  x,y: Real;

Begin
  ta := Time;
  x:=0.0;
  y:=9.9;
  WriteLn ('Start Real');
  For i:=1 to 10000 Do x:= x+ (y*y-y) / y;
  te:=Time;
  td:=te-ta;
  WriteLn ('Ende von Real ',x);
  WriteLn ('Zeit : ',Round(td));
End;

Procedure TrigLog;

Var
  i: Integer;
  x,y: Real;

Begin
  ta := Time;
  x := 0.0;
  y:= 9.9;
  WriteLn ('Start TrigLog');
  For i:=1 to 1000 Do x:=x+sin(arctan(cos(ln(y))));
  te:=Time;
  td:=te-ta;
  WriteLn ('Ende von TrigLog ',x);
  WriteLn ('Zeit : ',Round(td));
End;

Procedure Textscreen;

Var i: Integer;

Begin
  ta:=Time;
  WriteLn ('Start Text');
  For i:=1 to 1000 Do WriteLn ('1234567890qwertyuiop',i);
  te:=Time;
  td:=te-ta;
  WriteLn ('Ende von Text');
  WriteLn ('Zeit : ',Round(td));
End;

Procedure GraphScreen;
Var
  x,y,z :  Integer;

Begin
  ta:=Time;
  WriteLn ('Start Graphik');
  Hires;
{
  For z:=1 to 10 Do
}
  For x:=1 to 100 Do
    For y:=1 to 100 Do
      Plot (x,y);
  te:=Time;
  td:=te-ta;
  TextMode (BW80);
  WriteLn ('Ende von Graphik');
  WriteLn ('Zeit : ',Round(td));
End;

Procedure Store1;

Var
  i: Integer;
  x: String(.20.);
  TestFile : Text;

Begin
  ta := Time;
  WriteLn ('Start Store (Ramdisk - 10000 Datens{tze)');
  x:= '1234567890qwertyuiop';
  Assign (TestFile,'A:Test.$$$');
  Rewrite (Testfile);
  For i:=1 to 10000 Do Write (Testfile,x);
  Close (TestFile);
  Erase (Testfile);
  te:=Time;
  td:=te-ta;
  WriteLn ('Ende von Store (Ramdisk)');
  WriteLn ('Zeit :',Round(td));
End;

Procedure Store2;

Var
  i: Integer;
  x: String(.20.);
  TestFile : Text;

Begin
  ta := Time;
  WriteLn ('Start Store (Disk - 1000 Datens{tze)');
  x:= '1234567890qwertyuiop';
  Assign (TestFile,'C:Test.$$$');
  Rewrite (Testfile);
  For i:=1 to 1000 Do Write (Testfile,x);
  Close (TestFile);
  Erase (Testfile);
  te:=Time;
  td:=te-ta;
  WriteLn ('Ende von Store (Disk)');
  WriteLn ('Zeit :',Round(td));
End;

Procedure ConOut (C:Char);
Begin
  Inline ($4D/$CD/$F400)
End;

(* Hauptprogramm *)

Var Ch : Char;

Begin
  Write (TRM,^[,'[T0',^[,'[I0',^[,'S');
  CBreak := False;
  ConOutPtr := Addr (ConOut);
  Repeat
    ClrScr;
    WriteLn ('Benchmarks nach c`t - Bitte w{hlen:');
    WriteLn ('1 - Text');
    WriteLn ('2 - Graphik');
    WriteLn ('3 - Integer');
    WriteLn ('4 - Real');
    WriteLn ('5 - Triglog');
    WriteLn ('6 - Store Disk (Drive C)');
    WriteLn ('7 - Store Ramdisk');
    WriteLn ('A - Alles');
    WriteLn;
    WriteLn ('0 - Ende');
    Repeat Read (KBD,Ch); Ch := UpCase (Ch); Until Ch in (.'0'..'7','A'.);
    Case Ch of
     '0':Halt;
     '1':TextScreen;
     '2':GraphScreen;
     '3':IntMath;
     '4':RealMath;
     '5':TrigLog;
     '6':Store2;
     '7':Store1;
     'A': Begin
            TextScreen;
            td_MTX (.1.) := td;
            GraphScreen;
            td_MTX (.2.) := td;
            IntMath;
            td_MTX (.3.) := td;
            RealMath;
            td_MTX (.4.) := td;
            TrigLog;
            td_MTX (.5.) := td;
            Store2;
            td_MTX (.6.) := td;
            Store1;
            td_MTX (.7.) := td;
            WriteLn ('          Text   Graf  Int  Real  Trig  Store (Disc/Ramdisc)');
            Write   ('MTX 4MHz  ');
            For i:=1 to 7 Do Write (td_MTX4 (.i.):4:1,'  ');
            WriteLn;
            Write   ('XT 4.77   ');
            For i:=1 to 7 Do Write (td_XT4 (.i.):4:1,'  ');
            WriteLn;
            Write   ('MTX       ');
            For i:=1 to 7 Do Write (td_MTX (.i.):4:1,'  ');
            WriteLn;
            For i:=1 to 3 Do Mittel(.i.) := 0;
            For i:=1 to 5 Do Mittel(.1.) := Mittel(.1.) + td_MTX (.i.);
            For i:=1 to 5 Do Mittel(.2.) := Mittel(.2.) + td_MTX4 (.i.);
            For i:=1 to 5 Do Mittel(.3.) := Mittel(.3.) + td_XT4 (.i.);
            Takt := Mittel (.2.) / Mittel (.1.) * 4;
            WriteLn ('Taktfrequenz Z80: ',Takt:1:1,' MHz');
            Takt := Mittel (.3.) / Mittel (.1.) * 4.77;
            WriteLn ('entspricht einem XT mit ',Takt:1:2,' MHz (Test 1-5)');
            For i:=3 to 5 Do Mittel(.1.) := Mittel(.1.) + td_MTX (.i.);
            For i:=3 to 5 Do Mittel(.3.) := Mittel(.3.) + td_XT4 (.i.);
            Takt := Mittel (.3.) / Mittel (.1.) * 4.77;
            WriteLn ('entspricht einem XT mit ',Takt:1:2,' MHz (Test 3-5)');
            WriteLn;
            WriteLn ('F}r die Bestimmung der Taktfraquenz wird der Mittelwert');
            WriteLn ('der Messungen 1 - 5 zugrundegelegt!');
          End;
    End;
  WriteLn ('Bitte eine Taste dr}cken!');
  Repeat Until Keypressed;
  Until Ch = '0';
End.
